﻿# Article ID of the Software Update in Configuration Manager. Also referred to as the KB-article
$articleID = "3012973"
# Name of the update in Configuration Manager. This is not required, but might be needed if several updates are found within same Article ID
$updateName = ""
# A simple test to see if the update specified above indeed is deployed to the device
# Still using Get-WmiObject here, as I failed to successfully convert this into the Get-CmiInstance equivalent
$testUpdateID = Get-WmiObject -Namespace root\ccm\clientSDK -Query “SELECT * FROM CCM_SoftwareUpdate WHERE ArticleID = '$articleID' AND Name LIKE '%$updateName%'”
# If the update is deployed to the device
if (-NOT[string]::IsNullOrEmpty($testUpdateID)) {
    $RegistryPath = "HKCU:\SOFTWARE\imab.dk\WaaS\2004"
    # Create registry path for detection method if it does not exist
    if (-NOT(Test-Path -Path $RegistryPath)) { New-Item -Path $RegistryPath –Force }
    # Install the update and launch the Software Center into the updates tab. Write successful detection method to registry
    try {
        Invoke-WmiMethod -Namespace root\ccm\clientsdk -Class CCM_SoftwareUpdatesManager -Name InstallUpdates -ArgumentList (,$testUpdateID)
        if (Test-Path -Path "$env:windir\CCM\ClientUX\SCClient.exe") { Start-Process -FilePath "$env:windir\CCM\ClientUX\SCClient.exe" -ArgumentList "SoftwareCenter:Page=Updates" -WindowStyle Maximized }
        New-ItemProperty -Path $RegistryPath -Name "PSADT-FU-DetectionMethod" -Value 0 -PropertyType "String" -Force
    }
    # Write failed detection method to registry and exit PSADT with error code 1
    catch { 
        New-ItemProperty -Path $RegistryPath -Name "PSADT-FU-DetectionMethod" -Value 1 -PropertyType "String" -Force
        exit 1
    }
}
# Else exit PSADT with error code 1
else {
    exit 1
}
